@@ -5,7 +5,7 @@ fn main() {
         let (mut a, mut b) = (0, 1);
         while b < 200 {
             std::mem::swap(&mut a, &mut b);
-            b = a + b;
+            b += a;
             s.yield_(b);
         }
         done!();
