@@ -3,10 +3,7 @@
 //! Rust generator library
 //!
 
-#![cfg_attr(nightly, feature(asm))]
-#![cfg_attr(nightly, feature(repr_simd))]
 #![cfg_attr(nightly, feature(core_intrinsics))]
-#![cfg_attr(nightly, feature(naked_functions))]
 #![cfg_attr(nightly, feature(thread_local))]
 #![cfg_attr(test, deny(warnings))]
 #![deny(missing_docs)]
@@ -23,7 +20,7 @@ mod scope;
 mod stack;
 mod yield_;
 
-pub use crate::gen_impl::{Generator, GeneratorImpl, Gn};
+pub use crate::gen_impl::{Generator, Gn, LocalGenerator};
 pub use crate::rt::{get_local_data, is_generator, Error};
 pub use crate::scope::Scope;
 pub use crate::yield_::{
